#!/bin/bash

# Run SeaDAS OCSSW Level 2 processing for MODIS L1B 1KM input data.
# The MODIS L1B 1KM file and corresponding geolocation file are required.
# The arguments to this script are the MxD021KM and MOD03 HDF filenames.

# Set up OCSSW environment
export OCSSWROOT=$PWD/ocssw
source $OCSSWROOT/OCSSW_bash.env

# Get input MODIS MxD021KM and MOD03 HDF4 file names as created by SeaDAS
# (e.g., A2019202204626.L1B_LAC A2019202204626.GEO)
ifile=$1
geofile=$2

# Get input directory name, date, time
dir=$(dirname $ifile)
date=$(basename $ifile | cut -c2-8)
time=$(basename $ifile | cut -c9-12)

# Convert date in yyyyddd format to yyyymmdd format
year=$(echo $date | cut -c1-4)
jday=$(echo $date | cut -c5-7)
date=$(date -d "${year}0101 + ${jday} days - 1 days" +%Y%m%d)

# Set output file name in current directory
ofile=SEADAS_$(basename $ifile | cut -d. -f1).hdf

# Get ancillary meteorological data (two date/time values 24 hours apart are used so that ozone data are found)
time1=$(date -d "${date} ${time} - 1 days" +%Y%j%H%M%S)
time2=$(date -d "${date} ${time} - 0 days" +%Y%j%H%M%S)
getanc.py -v -s $time1
getanc.py -v -s $time2
cat $time1.anc $time2.anc > ancillary.par

# Run the OCSSW Level 2 processor
l2gen ifile=$ifile geofile=$geofile ofile=$ofile l2prod="default sst cdom_index epsilon" proc_land="1" proc_sst="1" oformat="hdf4" par=ancillary.par

# Clean up
rm *.anc ancillary.par ancillary_data.db
