#!/bin/bash

# Run SeaDAS OCSSW Level 2 processing for VIIRS SDR input data.
# All 16 VIIRS SVM SDR files and the corresponding GMTCO file are required.
# The arguments to this script are the SVM01 and GMTCO filenames.

# Set up OCSSW environment
export OCSSWROOT=$PWD/ocssw
source $OCSSWROOT/OCSSW_bash.env

# Get input VIIRS SVM01 and GMTCO SDR file names
svm_file=$1
geo_file=$2

# Get input directory name, date, time
dir=$(dirname $svm_file)
date=$(basename $svm_file | cut -d_ -f3 | cut -c2-9)
time=$(basename $svm_file | cut -d_ -f4 | cut -c2-5)

# Create temporary input file names in current directory
for file in $dir/*_d${date}_t${time}*.h5; do ln -f -s $file $(basename $file | cut -d_ -f1-5)".tmp.h5"; done
ifile=$(find . -name SVM01\*${date}\*${time}\*tmp.h5)
geofile=$(find . -name GMTCO\*${date}\*${time}\*tmp.h5)

# Set output file name in current directory
ofile=SEADAS_$(basename $ifile | cut -d_ -f2-4).hdf

# Get ancillary meteorological data (two date/time values 24 hours apart are used so that ozone data are found)
time1=$(date -d "${date} ${time} - 1 days" +%Y%j%H%M%S)
time2=$(date -d "${date} ${time} - 0 days" +%Y%j%H%M%S)
getanc.py -v -s $time1
getanc.py -v -s $time2
cat $time1.anc $time2.anc > ancillary.par

# Run the OCSSW Level 2 processor
l2gen ifile=$ifile geofile=$geofile ofile=$ofile l2prod="default sst cdom_index epsilon" proc_land="1" proc_sst="1" oformat="hdf4" par=ancillary.par \
  calfile="" gain="1,1,1,1,1,1,1,1,1,1"

# Clean up
rm *tmp.h5 *.anc ancillary.par ancillary_data.db
